==> trimou-core-1.6.2.Final-sources.jar: org/trimou/util/Strings.java <==
/*
 * Copyright 2013 Martin Kouba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trimou.util;

import org.trimou.annotations.Internal;

/**
 *
 * @author Martin Kouba
 */
@Internal
public final class Strings {

    public static final String EMPTY = "";

    public static final String GAP = " ";

    public static final String LINE_SEPARATOR = System
            .getProperty("line.separator");

    /**
     * Linux, BDS, etc.
     */
    public static final String LINE_SEPARATOR_LF = "\n";

    /**
     * DOS, OS/2, Microsoft Windows, etc.
     */
    public static final String LINE_SEPARATOR_CRLF = "\r\n";

    /**
     * Mac OS 9, ZX Spectrum :-), etc.
     */
    public static final String LINE_SEPARATOR_CR = "\r";

    public static final String SLASH = "/";

    public static final String FILE_SEPARATOR = System
            .getProperty("file.separator");

    public static final String DOT = ".";

    public static final String UNDERSCORE = "_";

    public static final String EQUALS = "=";

    public static final String NOT_AVAILABLE = "N/A";

}

==> trimou-core-1.8.2.Final-sources.jar: org/trimou/util/Strings.java <==
/*
 * Copyright 2013 Martin Kouba
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.trimou.util;

import org.trimou.annotations.Internal;

/**
 *
 * @author Martin Kouba
 */
@Internal
public final class Strings {

    public static final String EMPTY = "";

    public static final String GAP = " ";

    public static final String LINE_SEPARATOR = System
            .getProperty("line.separator");

    /**
     * Linux, BDS, etc.
     */
    public static final String LINE_SEPARATOR_LF = "\n";

    /**
     * DOS, OS/2, Microsoft Windows, etc.
     */
    public static final String LINE_SEPARATOR_CRLF = "\r\n";

    /**
     * Mac OS 9, ZX Spectrum :-), etc.
     */
    public static final String LINE_SEPARATOR_CR = "\r";

    public static final String SLASH = "/";

    public static final String FILE_SEPARATOR = System
            .getProperty("file.separator");

    public static final String DOT = ".";

    public static final String UNDERSCORE = "_";

    public static final String EQUALS = "=";

    public static final String NOT_AVAILABLE = "N/A";

    public static final String URL_PROCOTOL_FILE = "file";

    public static final String URI_PROCOTOL_JAR = "jar";

    public static final String THIS = "this";

    /**
     *
     * @param character
     * @return <code>true</code> if the char is a string literal separator,
     *         <code>false</code> otherwise
     */
    public static boolean isStringLiteralSeparator(char character) {
        return character == '"' || character == '\'';
    }

}
